========
prakriya
========


.. image:: https://img.shields.io/pypi/v/prakriya.svg
        :target: https://pypi.python.org/pypi/prakriya

.. image:: https://img.shields.io/travis/drdhaval2785/python-prakriya.svg
        :target: https://travis-ci.org/drdhaval2785/python-prakriya

.. image:: https://readthedocs.org/projects/prakriya/badge/?version=latest
        :target: https://prakriya.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/drdhaval2785/python-prakriya/shield.svg
     :target: https://pyup.io/repos/github/drdhaval2785/python-prakriya/
     :alt: Updates


prakriya is a package to derive information about given Sanskrit verb form.


* Free software: GNU General Public License v3
* Documentation: https://prakriya.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
